@@ -16,6 +16,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
+ * In addition, as a special exception, the copyright holders give permission to
+ * link this program with the OpenSSL project's "OpenSSL" library (or with
+ * modified versions of it that use the same license as the "OpenSSL" library),
+ * and distribute the linked executables. You must obey the GNU General Public
+ * License in all respects for all of the code used other than "OpenSSL".  If you
+ * modify file(s), you may extend this exception to your version of the file(s),
+ * but you are not obligated to do so. If you do not wish to do so, delete this
+ * exception statement from your version.
+ *
  * Contact : chris@qbittorrent.org
  */
 #include <QFileDialog>
@@ -931,13 +940,11 @@ void GUI::configureSession(bool deleteOptions) {
     setWindowTitle(tr("qBittorrent %1", "e.g: qBittorrent v0.x").arg(QString::fromUtf8(VERSION)));
   }
   displaySpeedInTitle = new_displaySpeedInTitle;
-  if(options->isToolbarDisplayed() != toolBar->isVisible()) {
-      if(options->isToolbarDisplayed()) {
-        toolBar->setVisible(true);
-        toolBar->layout()->setSpacing(7);
-      } else {
-        toolBar->setVisible(false);
-    }
+  if(options->isToolbarDisplayed()) {
+    toolBar->setVisible(true);
+    toolBar->layout()->setSpacing(7);
+  } else {
+    toolBar->setVisible(false);
   }
   unsigned int new_refreshInterval = options->getRefreshInterval();
   if(refreshInterval != new_refreshInterval) {
