@@ -16,6 +16,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
+ * In addition, as a special exception, the copyright holders give permission to
+ * link this program with the OpenSSL project's "OpenSSL" library (or with
+ * modified versions of it that use the same license as the "OpenSSL" library),
+ * and distribute the linked executables. You must obey the GNU General Public
+ * License in all respects for all of the code used other than "OpenSSL".  If you
+ * modify file(s), you may extend this exception to your version of the file(s),
+ * but you are not obligated to do so. If you do not wish to do so, delete this
+ * exception statement from your version.
+ *
  * Contact : chris@qbittorrent.org
  */
 
@@ -47,13 +56,14 @@ SearchTab::SearchTab(SearchEngine *parent) : QWidget()
     
     setLayout(box);
     // Set Search results list model
-    SearchListModel = new QStandardItemModel(0,5);
+    SearchListModel = new QStandardItemModel(0,6);
     SearchListModel->setHeaderData(SEARCH_NAME, Qt::Horizontal, tr("Name", "i.e: file name"));
     SearchListModel->setHeaderData(SEARCH_SIZE, Qt::Horizontal, tr("Size", "i.e: file size"));
     SearchListModel->setHeaderData(SEARCH_SEEDERS, Qt::Horizontal, tr("Seeders", "i.e: Number of full sources"));
     SearchListModel->setHeaderData(SEARCH_LEECHERS, Qt::Horizontal, tr("Leechers", "i.e: Number of partial sources"));
     SearchListModel->setHeaderData(SEARCH_ENGINE, Qt::Horizontal, tr("Search engine"));
     resultsBrowser->setModel(SearchListModel);
+    resultsBrowser->hideColumn(URL_COLUMN); // Hide url column
     SearchDelegate = new SearchListDelegate();
     resultsBrowser->setItemDelegate(SearchDelegate);
     // Make search list header clickable for sorting
@@ -128,7 +138,7 @@ void SearchTab::sortSearchListInt(int index, Qt::SortOrder sortOrder){
   for(int row=0; row<lines.size(); ++row){
     SearchListModel->insertRow(SearchListModel->rowCount());
     int sourceRow = lines[row].first;
-    for(int col=0; col<5; ++col){
+    for(int col=0; col<6; ++col){
       SearchListModel->setData(SearchListModel->index(nbRows_old+row, col), SearchListModel->data(SearchListModel->index(sourceRow, col)));
       SearchListModel->setData(SearchListModel->index(nbRows_old+row, col), SearchListModel->data(SearchListModel->index(sourceRow, col), Qt::ForegroundRole), Qt::ForegroundRole);
     }
@@ -148,7 +158,7 @@ void SearchTab::sortSearchListString(int index, Qt::SortOrder sortOrder){
   for(int row=0; row<nbRows_old; ++row){
     SearchListModel->insertRow(SearchListModel->rowCount());
     int sourceRow = lines[row].first;
-    for(int col=0; col<5; ++col){
+    for(int col=0; col<6; ++col){
       SearchListModel->setData(SearchListModel->index(nbRows_old+row, col), SearchListModel->data(SearchListModel->index(sourceRow, col)));
       SearchListModel->setData(SearchListModel->index(nbRows_old+row, col), SearchListModel->data(SearchListModel->index(sourceRow, col), Qt::ForegroundRole), Qt::ForegroundRole);
     }
