@@ -16,12 +16,22 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
+ * In addition, as a special exception, the copyright holders give permission to
+ * link this program with the OpenSSL project's "OpenSSL" library (or with
+ * modified versions of it that use the same license as the "OpenSSL" library),
+ * and distribute the linked executables. You must obey the GNU General Public
+ * License in all respects for all of the code used other than "OpenSSL".  If you
+ * modify file(s), you may extend this exception to your version of the file(s),
+ * but you are not obligated to do so. If you do not wish to do so, delete this
+ * exception statement from your version.
+ *
  * Contact : chris@qbittorrent.org
  */
 
 #include "engineSelectDlg.h"
 #include "downloadThread.h"
 #include "misc.h"
+#include "ico.h"
 #include "pluginSource.h"
 #include <QProcess>
 #include <QHeaderView>
@@ -122,7 +132,7 @@ void engineSelectDlg::saveSettings() {
 
 void engineSelectDlg::on_updateButton_clicked() {
   // Download version file from primary server
-  downloader->downloadUrl("http://www.dchris.eu/search_engine/versions.txt");
+  downloader->downloadUrl("http://www.dchris.eu/search_engine2/versions.txt");
 }
 
 void engineSelectDlg::toggleEngineState(QTreeWidgetItem *item, int) {
@@ -323,8 +333,13 @@ void engineSelectDlg::loadSupportedSearchEngines(bool first) {
       // Good, we already have the icon
       item->setData(ENGINE_NAME, Qt::DecorationRole, QVariant(QIcon(iconPath)));
     } else {
-      // Icon is missing, we must download it
-      downloader->downloadUrl(line.at(1)+"/favicon.ico");
+      iconPath = misc::qBittorrentPath()+"search_engine"+QDir::separator()+"engines"+QDir::separator()+id+".ico";
+      if(QFile::exists(iconPath)) { // ICO support
+        item->setData(ENGINE_NAME, Qt::DecorationRole, QVariant(QIcon(iconPath)));
+      } else {
+        // Icon is missing, we must download it
+        downloader->downloadUrl(line.at(1)+"/favicon.ico");
+      }
     }
     if(installed_engines.value(id, true))
       setRowColor(i, "green");
@@ -439,7 +454,9 @@ void engineSelectDlg::installZipPlugin(QString path) {
       continue;
     // Check if we already have a favicon for this plugin
     QString iconPath = misc::qBittorrentPath()+"search_engine"+QDir::separator()+"engines"+QDir::separator()+plugin_name+".png";
-    if(QFile::exists(iconPath)) continue;
+    if(QFile::exists(iconPath)) {
+      QFile::remove(iconPath);
+    }
     ZZIP_FILE* fp = zzip_file_open(dir, favicon.toUtf8().data(), 0);
     if(fp) {
       QFile dest_icon(iconPath);
@@ -611,7 +628,13 @@ void engineSelectDlg::processDownloadedFile(QString url, QString filePath) {
       QTreeWidgetItem *item;
       foreach(item, items){
         QString id = item->text(ENGINE_ID);
-        QString iconPath = misc::qBittorrentPath()+"search_engine"+QDir::separator()+"engines"+QDir::separator()+id+".png";
+        QString iconPath;
+        QFile icon(filePath);
+        icon.open(QIODevice::ReadOnly);
+        if(ICOHandler::canRead(&icon))
+          iconPath = misc::qBittorrentPath()+"search_engine"+QDir::separator()+"engines"+QDir::separator()+id+".ico";
+        else
+          iconPath = misc::qBittorrentPath()+"search_engine"+QDir::separator()+"engines"+QDir::separator()+id+".png";
         QFile::copy(filePath, iconPath);
         item->setData(ENGINE_NAME, Qt::DecorationRole, QVariant(QIcon(iconPath)));
       }
@@ -620,16 +643,16 @@ void engineSelectDlg::processDownloadedFile(QString url, QString filePath) {
     QFile::remove(filePath);
     return;
   }
-  if(url == "http://www.dchris.eu/search_engine/versions.txt") {
-    if(!parseVersionsFile(filePath, "http://www.dchris.eu/search_engine/")) {
+  if(url == "http://www.dchris.eu/search_engine2/versions.txt") {
+    if(!parseVersionsFile(filePath, "http://www.dchris.eu/search_engine2/")) {
       qDebug("Primary update server failed, try secondary");
-      downloader->downloadUrl("http://hydr0g3n.free.fr/search_engine/versions.txt");
+      downloader->downloadUrl("http://hydr0g3n.free.fr/search_engine2/versions.txt");
     }
     QFile::remove(filePath);
     return;
   }
-  if(url == "http://hydr0g3n.free.fr/search_engine/versions.txt") {
-    if(!parseVersionsFile(filePath, "http://hydr0g3n.free.fr/search_engine/")) {
+  if(url == "http://hydr0g3n.free.fr/search_engine2/versions.txt") {
+    if(!parseVersionsFile(filePath, "http://hydr0g3n.free.fr/search_engine2/")) {
       QMessageBox::warning(this, tr("Search plugin update")+" -- "+tr("qBittorrent"), tr("Sorry, update server is temporarily unavailable."));
     }
     QFile::remove(filePath);
@@ -657,13 +680,13 @@ void engineSelectDlg::handleDownloadFailure(QString url, QString reason) {
     qDebug("Could not download favicon: %s, reason: %s", url.toUtf8().data(), reason.toUtf8().data());
     return;
   }
-  if(url == "http://www.dchris.eu/search_engine/versions.txt") {
+  if(url == "http://www.dchris.eu/search_engine2/versions.txt") {
     // Primary update server failed, try secondary
     qDebug("Primary update server failed, try secondary");
-    downloader->downloadUrl("http://hydr0g3n.free.fr/search_engine/versions.txt");
+    downloader->downloadUrl("http://hydr0g3n.free.fr/search_engine2/versions.txt");
     return;
   }
-  if(url == "http://hydr0g3n.free.fr/search_engine/versions.txt") {
+  if(url == "http://hydr0g3n.free.fr/search_engine2/versions.txt") {
     QMessageBox::warning(this, tr("Search plugin update")+" -- "+tr("qBittorrent"), tr("Sorry, update server is temporarily unavailable."));
     return;
   }
