@@ -16,6 +16,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
+ * In addition, as a special exception, the copyright holders give permission to
+ * link this program with the OpenSSL project's "OpenSSL" library (or with
+ * modified versions of it that use the same license as the "OpenSSL" library),
+ * and distribute the linked executables. You must obey the GNU General Public
+ * License in all respects for all of the code used other than "OpenSSL".  If you
+ * modify file(s), you may extend this exception to your version of the file(s),
+ * but you are not obligated to do so. If you do not wish to do so, delete this
+ * exception statement from your version.
+ *
  * Contact : chris@qbittorrent.org, arnaud@qbittorrent.org
  */
 
@@ -320,6 +329,8 @@ class RssStream : public QObject{
     }
 
     ~RssStream(){
+      QSettings qBTRSS("qBittorrent-rss");
+      qBTRSS.setValue(url, getAllReadHashes());
       removeAllItems();
       if(QFile::exists(filePath))
         QFile::remove(filePath);
@@ -327,6 +338,15 @@ class RssStream : public QObject{
         QFile::remove(iconPath);
     }
 
+    QStringList getAllReadHashes() {
+        QStringList hashes;
+        foreach(RssItem *item, listItem) {
+            if(item->isRead())
+                hashes << item->getHash();
+        }
+        return hashes;
+    }
+
     // delete all the items saved
     void removeAllItems() {
       qDeleteAll(listItem);
@@ -462,6 +482,11 @@ class RssStream : public QObject{
   private:
     // read and create items from a rss document
     short readDoc(const QDomDocument& doc) {
+      QStringList old_items;
+      if(!refreshed) {
+        QSettings qBTRSS("qBittorrent-rss");
+        old_items = qBTRSS.value(this->url, QVariant()).toStringList();
+      }
       // is it a rss file ?
       QDomElement root = doc.documentElement();
       if(root.tagName() == QString::fromUtf8("html")){
@@ -493,10 +518,13 @@ class RssStream : public QObject{
 	      image = property.text();
 	    else if(property.tagName() == "item") {
               RssItem * item = new RssItem(property);
-              if(!itemAlreadyExists(item->getHash()))
+              if(!itemAlreadyExists(item->getHash())) {
+                if(!refreshed && old_items.contains(item->getHash()))
+                    item->setRead();
                 listItem.append(item);
-              else
+              } else {
                 delete item;
+              }
 	    }
 	    property = property.nextSibling().toElement();
 	  }
