@@ -16,6 +16,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
+ * In addition, as a special exception, the copyright holders give permission to
+ * link this program with the OpenSSL project's "OpenSSL" library (or with
+ * modified versions of it that use the same license as the "OpenSSL" library),
+ * and distribute the linked executables. You must obey the GNU General Public
+ * License in all respects for all of the code used other than "OpenSSL".  If you
+ * modify file(s), you may extend this exception to your version of the file(s),
+ * but you are not obligated to do so. If you do not wish to do so, delete this
+ * exception statement from your version.
+ *
  * Contact : chris@qbittorrent.org
  */
 
@@ -42,7 +51,6 @@
 /*SEARCH ENGINE START*/
 SearchEngine::SearchEngine(bittorrent *BTSession, QSystemTrayIcon *myTrayIcon, bool systrayIntegration) : QWidget(), BTSession(BTSession), myTrayIcon(myTrayIcon), systrayIntegration(systrayIntegration){
   setupUi(this);
-  downloader = new downloadThread(this);
   // new qCompleter to the search pattern
   startSearchHistory();
   searchCompleter = new QCompleter(searchHistory, this);
@@ -58,6 +66,8 @@ SearchEngine::SearchEngine(bittorrent *BTSession, QSystemTrayIcon *myTrayIcon, b
   search_stopped = false;
   // Creating Search Process
   searchProcess = new QProcess(this);
+  QStringList env = QProcess::systemEnvironment();
+  searchProcess->setEnvironment(env);
   connect(searchProcess, SIGNAL(started()), this, SLOT(searchStarted()));
   connect(searchProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(readSearchOutput()));
   connect(searchProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(searchFinished(int,QProcess::ExitStatus)));
@@ -77,10 +87,14 @@ SearchEngine::~SearchEngine(){
   saveSearchHistory();
   searchProcess->kill();
   searchProcess->waitForFinished();
+	foreach(QProcess *downloader, downloaders) {
+		downloader->kill();
+		downloader->waitForFinished();
+		delete downloader;
+	}
   delete searchTimeout;
   delete searchProcess;
   delete searchCompleter;
-  delete downloader;
 }
 
 void SearchEngine::tab_changed(int t)
@@ -188,6 +202,18 @@ void SearchEngine::on_search_button_clicked(){
   searchTimeout->start(180000); // 3min
 }
 
+void SearchEngine::downloadTorrent(QString engine_url, QString torrent_url) {
+		QProcess *downloadProcess = new QProcess(this);
+		connect(downloadProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(downloadFinished(int,QProcess::ExitStatus)));
+		downloaders << downloadProcess;
+		QStringList params;
+		params << misc::qBittorrentPath()+"search_engine"+QDir::separator()+"nova2dl.py";
+		params << engine_url;
+		params << torrent_url;
+		// Launch search
+		downloadProcess->start("python", params, QIODevice::ReadOnly);
+}
+
 void SearchEngine::searchStarted(){
   // Update SearchEngine widgets
   search_status->setText(tr("Searching..."));
@@ -204,9 +230,11 @@ void SearchEngine::searchStarted(){
 void SearchEngine::downloadSelectedItem(const QModelIndex& index){
   int row = index.row();
   // Get Item url
-  QString url = searchResultsUrls.value(all_tab.at(tabWidget->currentIndex())->getCurrentSearchListModel()->data(all_tab.at(tabWidget->currentIndex())->getCurrentSearchListModel()->index(row, NAME)).toString());
+  QStandardItemModel *model = all_tab.at(tabWidget->currentIndex())->getCurrentSearchListModel();
+	QString engine_url = model->data(model->index(index.row(), ENGINE_URL_COLUMN)).toString();
+  QString torrent_url = model->data(model->index(index.row(), URL_COLUMN)).toString();
   // Download from url
-  BTSession->downloadFromUrl(url);
+  downloadTorrent(engine_url, torrent_url);
   // Set item color to RED
   all_tab.at(tabWidget->currentIndex())->setRowColor(row, "red");
 }
@@ -224,11 +252,27 @@ void SearchEngine::readSearchOutput(){
   }
   search_result_line_truncated = lines_list.takeLast().trimmed();
   foreach(const QByteArray &line, lines_list){
-    appendSearchResult(QString(line));
+    appendSearchResult(QString::fromUtf8(line));
   }
   currentSearchTab->getCurrentLabel()->setText(tr("Results")+QString::fromUtf8(" <i>(")+misc::toQString(nb_search_results)+QString::fromUtf8(")</i>:"));
 }
 
+void SearchEngine::downloadFinished(int exitcode, QProcess::ExitStatus) {
+		QProcess *downloadProcess = (QProcess*)sender();
+		if(exitcode == 0) {
+				QString line = QString::fromUtf8(downloadProcess->readAllStandardOutput()).trimmed();
+				QStringList parts = line.split(' ');
+				if(parts.size() == 2) {
+						QString path = parts[0];
+						QString url = parts[1];
+						BTSession->processDownloadedFile(url, path);
+				}
+		}
+		qDebug("Deleting downloadProcess");
+		downloaders.removeOne(downloadProcess);
+		delete downloadProcess;
+}
+
 // Update nova.py search plugin if necessary
 void SearchEngine::updateNova() {
   qDebug("Updating nova");
@@ -256,6 +300,14 @@ void SearchEngine::updateNova() {
   // Set permissions
   QFile::Permissions perm=QFile::ReadOwner | QFile::WriteOwner | QFile::ExeOwner | QFile::ReadUser | QFile::WriteUser | QFile::ExeUser | QFile::ReadGroup | QFile::ReadGroup;
   QFile(misc::qBittorrentPath()+"search_engine"+QDir::separator()+"nova2.py").setPermissions(perm);
+	filePath = misc::qBittorrentPath()+"search_engine"+QDir::separator()+"nova2dl.py";
+	if(misc::getPluginVersion(":/search_engine/nova2dl.py") > misc::getPluginVersion(filePath)) {
+    if(QFile::exists(filePath)){
+      QFile::remove(filePath);
+    }
+    QFile::copy(":/search_engine/nova2dl.py", filePath);
+  }
+  QFile(misc::qBittorrentPath()+"search_engine"+QDir::separator()+"nova2dl.py").setPermissions(perm);
   filePath = misc::qBittorrentPath()+"search_engine"+QDir::separator()+"novaprinter.py";
   if(misc::getPluginVersion(":/search_engine/novaprinter.py") > misc::getPluginVersion(filePath)) {
     if(QFile::exists(filePath)){
@@ -263,6 +315,15 @@ void SearchEngine::updateNova() {
     }
     QFile::copy(":/search_engine/novaprinter.py", filePath);
   }
+  QFile(misc::qBittorrentPath()+"search_engine"+QDir::separator()+"novaprinter.py").setPermissions(perm);
+  filePath = misc::qBittorrentPath()+"search_engine"+QDir::separator()+"helpers.py";
+  if(misc::getPluginVersion(":/search_engine/helpers.py") > misc::getPluginVersion(filePath)) {
+    if(QFile::exists(filePath)){
+      QFile::remove(filePath);
+    }
+    QFile::copy(":/search_engine/helpers.py", filePath);
+  }
+	QFile(misc::qBittorrentPath()+"search_engine"+QDir::separator()+"helpers.py").setPermissions(perm);
   QString destDir = misc::qBittorrentPath()+"search_engine"+QDir::separator()+"engines"+QDir::separator();
   QDir shipped_subDir(":/search_engine/engines/");
   QStringList files = shipped_subDir.entryList();
@@ -326,23 +387,19 @@ void SearchEngine::appendSearchResult(QString line){
   if(parts.size() != 6){
     return;
   }
-  QString url = parts.takeFirst();
-  QString filename = parts.first();
-  // XXX: Two results can't have the same name (right?)
-  if(searchResultsUrls.contains(filename)){
-    return;
-  }
+  QString url = parts.takeFirst().trimmed();
+  QString filename = parts.first().trimmed();
+  parts << url;
   // Add item to search result list
   int row = currentSearchTab->getCurrentSearchListModel()->rowCount();
   currentSearchTab->getCurrentSearchListModel()->insertRow(row);
-  for(int i=0; i<5; ++i){
-    if(parts.at(i).toFloat() == -1 && i != SIZE)
+  for(int i=0; i<6; ++i){
+    if(parts.at(i).trimmed().toFloat() == -1 && i != SIZE)
       currentSearchTab->getCurrentSearchListModel()->setData(currentSearchTab->getCurrentSearchListModel()->index(row, i), tr("Unknown"));
     else
-      currentSearchTab->getCurrentSearchListModel()->setData(currentSearchTab->getCurrentSearchListModel()->index(row, i), QVariant(parts.at(i)));
+      currentSearchTab->getCurrentSearchListModel()->setData(currentSearchTab->getCurrentSearchListModel()->index(row, i), QVariant(parts.at(i).trimmed()));
   }
   // Add url to searchResultsUrls associative array
-  searchResultsUrls.insert(filename, url);
   no_search_results = false;
   ++nb_search_results;
   // Enable clear & download buttons
@@ -393,8 +450,10 @@ void SearchEngine::on_download_button_clicked(){
   foreach(const QModelIndex &index, selectedIndexes){
     if(index.column() == NAME){
       // Get Item url
-      QString url = searchResultsUrls.value(index.data().toString());
-      BTSession->downloadFromUrl(url);
+      QStandardItemModel *model = all_tab.at(tabWidget->currentIndex())->getCurrentSearchListModel();
+      QString torrent_url = model->data(model->index(index.row(), URL_COLUMN)).toString();
+			QString engine_url = model->data(model->index(index.row(), ENGINE_URL_COLUMN)).toString();
+      downloadTorrent(engine_url, torrent_url);
       all_tab.at(tabWidget->currentIndex())->setRowColor(index.row(), "red");
     }
   }
