@@ -1,4 +1,4 @@
-#VERSION: 1.13
+#VERSION: 1.22
 #AUTHORS: Fabien Devaux (fab@gnux.info)
 
 # Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 from novaprinter import prettyPrinter
-import urllib
+from helpers import retrieve_url, download_file
 from xml.dom import minidom
 import re
 
@@ -34,6 +34,9 @@ class mininova(object):
 	url = 'http://www.mininova.org'
 	name = 'Mininova'
 	table_items = 'added cat name size seeds leech'.split()
+	
+	def download_torrent(self, info):
+		print download_file(info)
 
 	def search(self, what):
 
@@ -65,11 +68,12 @@ class mininova(object):
 		page = 1
 		while True and page<11:
 			res = 0
-			dat = urllib.urlopen(self.url+'/search/%s/seeds/%d'%(what, page)).read().decode('utf-8', 'replace')
+			dat = retrieve_url(self.url+'/search/%s/seeds/%d'%(what, page))
 			dat = re.sub("<a href=\"http://www.boardreader.com/index.php.*\"", "<a href=\"plop\"", dat)
 			dat = re.sub("<=", "&lt;=", dat)
 			dat = re.sub("&\s", "&amp; ", dat)
-			x = minidom.parseString(dat.encode('utf-8', 'replace'))
+			dat = re.sub("&(?!amp)", "&amp;", dat)
+			x = minidom.parseString(dat)
 			table = x.getElementsByTagName('table').item(0)
 			if not table: return
 			for tr in table.getElementsByTagName('tr'):
